layouttools.SpacingIndication
=============================

.. inheritance-diagram:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication
   :private-bases:

.. autoclass:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.normalized_spacing_duration

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.proportional_notation_duration

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.tempo_indication

Special Methods
---------------

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__eq__

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__ne__

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__repr__

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__str__

   .. note:: Inherited from `__builtin__.object`
